/**
 * Simple utilities to handle responses from ajax calls.
 */

function parseJSON(response) {
  return response.json();
}

function checkError(json) {
  if (json.type && json.type === 'error') {
    const error = new Error(json.message);
    throw error;
  }
  return json;
}

function apiHandler(onSuccess, onError) {
  return json => {
    if (json.type && json.type === 'error') {
      onError(json.message);
    }
    else {
      onSuccess(json);
    }
  };
}

function makeQueryString(obj) {
  return Object.keys(obj)
    .map(key => `${key}=${encodeURIComponent(obj[key])}`)
    .join('&');
}

module.exports = {
  parseJSON,
  checkError,
  apiHandler,
  makeQueryString
};
